<?php

namespace AcyChecker\Classes;

use AcyChecker\Libraries\AcycClass;
use AcyChecker\Services\ApiService;
use AcyChecker\Services\DebugService;
use AcyChecker\Services\SecurityService;
use AcyCheckerCmsServices\Database;

class AcymailingUserClass extends AcycClass
{
    public function countUsers()
    {
        return Database::loadResult('SELECT COUNT(*) FROM #__acym_user');
    }

    public function getLastYearUsers()
    {
        $lastYear = date('Y-m-d H:i', strtotime('-1 year'));

        return Database::loadResult('SELECT COUNT(*) FROM #__acym_user WHERE creation_date > '.Database::escapeDB($lastYear));
    }

    public function getUsersEmail($offset = 0, $limit = 5000, $fromCron = false, $onlyNew = false, $lists = [])
    {
        // We filter the users if we need to
        $filters = [];
        if ($onlyNew) $filters[] = ' email NOT IN (SELECT email FROM #__acyc_test)';
        if ($fromCron) $filters[] = 'user.active = 1';

        $query = 'SELECT user.email from #__acym_user AS user ';

        // If we selected list we only select users subscribed to it
        if (!empty($lists)) {
            SecurityService::arrayToInteger($lists);
            $query .= 'JOIN #__acym_user_has_list AS user_list ON user.id = user_list.user_id AND user_list.list_id IN ('.implode(',', $lists).')';
        }

        $queryWhere = empty($filters) ? '' : ' WHERE ('.implode(') AND (', $filters).')';

        $query .= ' '.$queryWhere.' LIMIT '.$offset.','.$limit;

        return Database::loadResultArray($query);
    }

    public function handleBatchCallback($emailsResults, &$allTests)
    {
        // We get the conditions selected
        $conditionsSelected = $this->config->get('conditions_selected', []);
        if (empty($conditionsSelected)) {
            DebugService::logMessage('callback_controller.log', 'No conditions set in the configuration');

            return;
        }

        $conditionsSelected = explode(',', $conditionsSelected);
        if (empty($conditionsSelected)) {
            DebugService::logMessage('callback_controller.log', 'No conditions set in the configuration');

            return;
        }

        // We get all the emails in the test
        $emails = array_column($emailsResults, 'email');

        foreach ($emails as $key => $email) {
            $emails[$key] = Database::escapeDB($email);
        }

        // We filter with the email in the database
        try {
            $emailsInAcymailing = Database::loadResultArray('SELECT email FROM #__acym_user WHERE email in ('.implode(',', $emails).')');
        } catch (\Exception $exception) {
            DebugService::logMessage('callback_controller.log', 'Error on getting AcyMailing users from results - '.$exception->getMessage());

            return;
        }

        $apiService = new ApiService();
        $blockEmail = [];

        // We check if we have to block users or not
        foreach ($emailsInAcymailing as $email) {
            $arrayKey = array_search($email, array_column($emailsResults, 'email'));
            // We test if the email is ok for the condition
            $emailOk = $apiService->isEmailAccepted($emailsResults[$arrayKey], $conditionsSelected);
            if ($emailOk === true) continue;

            $blockEmail[] = Database::escapeDB($email);
            // We set the reason why we block the user
            if (!empty($allTests)) $allTests[$email]['block_reason'] = Database::escapeDB($emailOk);
        }

        // We block all the users
        $updateQuery = 'UPDATE #__acym_user SET active = 0 WHERE email IN ('.implode(',', $blockEmail).')';

        try {
            Database::query($updateQuery);
        } catch (\Exception $exception) {
            DebugService::logMessage('callback_controller.log', 'Error on request to block AcyMailing users - '.$exception->getMessage());
        }
    }
}
