<?php

namespace AcyChecker\Controllers;

use AcyChecker\Classes\AcymailingListClass;
use AcyChecker\Libraries\AcycController;
use AcyChecker\Services\ConfigurationService;
use AcyChecker\Services\CronService;
use AcyCheckerCmsServices\Language;
use AcyCheckerCmsServices\Security;
use AcyCheckerCmsServices\Url;
use AcyCheckerCmsServices\User;

class ConfigurationController extends AcycController
{
    public function __construct()
    {
        parent::__construct();

        $this->name = 'Configuration';
    }

    public function defaultTask()
    {
        $this->layout = 'default';

        $data = [];

        ConfigurationService::prepareTableSelect($data);
        ConfigurationService::prepareConditionSelect($data);
        $this->prepareExecutionSelect($data);
        $this->prepareCurrentConfig($data);

        $data['tables_filters'] = [
            'cms' => [
                'values' => [],
                'text' => 'CMS',
            ],
        ];
        $this->prepareCmsGroupFilter($data);

        if ($this->isAcymailingInstalled) {
            $data['tables_filters']['acymailing'] = [
                'values' => [],
                'text' => 'AcyMailing',
            ];
            $this->prepareAcyMailingListFilter($data);
        }

        $this->breadcrumb[Language::translation('ACYC_CLEAN_DATABASE')] = Url::completeLink('configuration');

        $this->display($data);
    }

    private function prepareExecutionSelect(&$data)
    {
        $data['execution_select'] = [
            [
                'value' => 'now',
                'text' => Language::translation('ACYC_RIGHT_NOW'),
            ],
            [
                'value' => 'week',
                'text' => Language::translation('ACYC_EVERY_WEEK'),
            ],
            [
                'value' => 'month',
                'text' => Language::translation('ACYC_EVERY_MONTH'),
            ],
        ];
    }

    private function prepareCmsGroupFilter(&$data)
    {
        $cmsGroups = User::getGroups();

        foreach ($cmsGroups as $group) {
            $data['tables_filters']['cms']['values'][$group->id] = $group->text;
        }
    }

    private function prepareAcyMailingListFilter(&$data)
    {
        if ($this->isAcymailingInstalled) {
            $acymailingListClass = new AcymailingListClass();
            $data['tables_filters']['acymailing']['values'] = $acymailingListClass->getAllListsForSelect();
        }
    }

    private function prepareCurrentConfig(&$data)
    {
        $currentConfig = [];

        $currentConfig['tables_selected'] = $this->config->get('tables_selected', []);
        if (!empty($currentConfig['tables_selected'])) $currentConfig['tables_selected'] = explode(',', $currentConfig['tables_selected']);

        $currentConfig['table_filter_cms'] = $this->config->get('table_filter_cms', []);
        if (!empty($currentConfig['table_filter_cms'])) $currentConfig['table_filter_cms'] = explode(',', $currentConfig['table_filter_cms']);

        $currentConfig['table_filter_acymailing'] = $this->config->get('table_filter_acymailing', []);
        if (!empty($currentConfig['table_filter_acymailing'])) $currentConfig['table_filter_acymailing'] = explode(',', $currentConfig['table_filter_acymailing']);

        $currentConfig['conditions_selected'] = $this->config->get('conditions_selected', []);
        if (!empty($currentConfig['conditions_selected'])) $currentConfig['conditions_selected'] = explode(',', $currentConfig['conditions_selected']);

        $currentConfig['execution_selected'] = $this->config->get('execution_selected', 'week');

        $currentConfig['only_newly'] = $this->config->get('only_newly', 1);

        $data['current_config'] = $currentConfig;
    }

    protected function store()
    {
        $config = Security::getVar('array', 'acyc_config');

        $this->config->save($config);
    }

    public function save()
    {
        $this->store();
        $this->defaultTask();
    }

    public function process()
    {
        $this->store();

        $cronService = new CronService();
        $cronService->processBatches();

        $this->defaultTask();
    }
}
