<?php

namespace AcyChecker\Services;

use AcyChecker\Libraries\AcycObject;
use AcyCheckerCmsServices\Database;
use AcyCheckerCmsServices\Date;
use AcyCheckerCmsServices\Language;

class DateService extends AcycObject
{
    public static function getDate($time = 0, $format = '%d %B %Y %H:%M')
    {
        if (empty($time)) return '';

        if (is_numeric($format)) {
            $format = Language::translation('ACYC_DATE_FORMAT_LC'.$format);
        }

        $format = str_replace(
            ['%A', '%d', '%B', '%m', '%Y', '%y', '%H', '%M', '%S', '%a', '%I', '%p', '%w'],
            ['l', 'd', 'F', 'm', 'Y', 'y', 'H', 'i', 's', 'D', 'h', 'a', 'w'],
            $format
        );

        //Not sure why but sometimes it fails... so lets try to catch the error...
        try {
            return DateService::date($time, $format, false);
        } catch (\Exception $e) {
            return date($format, $time);
        }
    }

    public static function date($time = 'now', $format = null, $useTz = true, $translate = true)
    {
        if ($time == 'now') {
            $time = time();
        }

        if (is_numeric($time)) {
            $time = Date::dateTimeCMS((int)$time);
        }

        if (!$format || (strpos($format, 'ACYM_DATE_FORMAT') !== false && Language::translation($format) == $format)) {
            $format = 'ACYM_DATE_FORMAT_LC1';
        }
        if (strpos($format, 'ACYM_DATE') !== false) $format = Language::translation($format);

        //Don't use timezone
        if ($useTz === false) {
            $date = new \DateTime($time);

            if ($translate) {
                return DateService::translateDate($date->format($format));
            } else {
                return $date->format($format);
            }
        } else {
            //use timezone
            $cmsOffset = Database::getCMSConfig('offset');

            $timezone = new \DateTimeZone($cmsOffset);

            if (!is_numeric($cmsOffset)) {
                $cmsOffset = $timezone->getOffset(new \DateTime);
            }

            if ($translate) {
                return DateService::translateDate(date($format, strtotime($time) + $cmsOffset));
            } else {
                return date($format, strtotime($time) + $cmsOffset);
            }
        }
    }

    public static function translateDate($date)
    {
        $map = [
            'January' => 'ACYC_JANUARY',
            'February' => 'ACYC_FEBRUARY',
            'March' => 'ACYC_MARCH',
            'April' => 'ACYC_APRIL',
            'May' => 'ACYC_MAY',
            'June' => 'ACYC_JUNE',
            'July' => 'ACYC_JULY',
            'August' => 'ACYC_AUGUST',
            'September' => 'ACYC_SEPTEMBER',
            'October' => 'ACYC_OCTOBER',
            'November' => 'ACYC_NOVEMBER',
            'December' => 'ACYC_DECEMBER',
            'Monday' => 'ACYC_MONDAY',
            'Tuesday' => 'ACYC_TUESDAY',
            'Wednesday' => 'ACYC_WEDNESDAY',
            'Thursday' => 'ACYC_THURSDAY',
            'Friday' => 'ACYC_FRIDAY',
            'Saturday' => 'ACYC_SATURDAY',
            'Sunday' => 'ACYC_SUNDAY',
        ];

        foreach ($map as $english => $translationKey) {
            $translation = Language::translation($translationKey);
            if ($translation == $translationKey) {
                continue;
            }

            $date = preg_replace('#'.preg_quote($english).'( |,|$)#i', $translation.'$1', $date);
            $date = preg_replace('#'.preg_quote(substr($english, 0, 3)).'( |,|$)#i', mb_substr($translation, 0, 3).'$1', $date);
        }

        return $date;
    }
}
